@@ -17,4 +17,6 @@
 
 cd build
 bash build_docker.sh
-sudo docker-compose -f $GOPATH/src/github.com/apache/servicecomb-kie/deployments/docker/docker-compose.yaml up -d
\ No newline at end of file
+cd "../$(dirname "$0")"
+sudo docker-compose -f ../../deployments/docker/docker-compose.yaml down
+sudo docker-compose -f ../../deployments/docker/docker-compose.yaml up -d
