@@ -19,7 +19,14 @@ package config
 
 //Config is yaml file struct
 type Config struct {
-	DB DB `yaml:"db"`
+	DB   DB   `yaml:"db"`
+	RBAC RBAC `yaml:"rbac"`
+	//config from cli
+	ConfigFile     string
+	NodeName       string
+	ListenPeerAddr string
+	PeerAddr       string
+	AdvertiseAddr  string
 }
 
 //DB is yaml file struct to set mongodb config
@@ -29,4 +36,11 @@ type DB struct {
 	SSLEnabled bool   `yaml:"sslEnabled"`
 	RootCA     string `yaml:"rootCAFile"`
 	Timeout    string `yaml:"timeout"`
+	VerifyPeer bool   `yaml:"verifyPeer"`
+}
+
+//RBAC is rbac config
+type RBAC struct {
+	Enabled    bool   `yaml:"enabled"`
+	PubKeyFile string `yaml:"rsaPublicKeyFile"`
 }
